package tpadm;

use strict;
use vars qw($VERSION @ISA @EXPORT);
require Exporter;

$VERSION = 1.00;

@ISA = qw(Exporter);
@EXPORT = qw(
	TA_DMMINENCRYPTBITS
	TA_DMBUFTYPE
	TA_TLOGDATA
	TA_CONTEXTID
	TA_USIGNAL
	TA_MEMNONPERSIST
	TA_LOWPRIORITY
	TA_NUMPOST
	TA_SHM_CONTENTIONS
	TA_CURMEMNONPERSIST
	TA_MAXQUEUES
	TA_AUTHSVC
	TA_LDBAL
	TA_DEFEXPIRATIONTIME
	TA_TOTWKQUEUED
	TA_DEFDELIVERYPOLICY
	TA_HWACLCACHE
	TA_SRVGRP
	TA_THREADID
	TA_MAXBUFTYPE
	TA_EJBCACHE_FLUSH
	TA_COMPONENTS
	TA_ULOGTIME
	TA_GRPNO
	TA_DEVOFFSET
	TA_CURWSCLIENTS
	TA_DUMMYSTATE
	TA_MAXSENDLEN
	TA_DMLSVCNUMACT
	TA_DMLOAD
	TA_PASSWD
	TA_MORE
	TA_SEC_PRINCIPAL_LOCATION
	TA_DMINRECSTYPE
	TA_MAXACTIONS
	TA_RQPERM
	TA_MEMFILTERS
	TA_NUMREQ
	TA_TESTONRESERVE
	TA_DMSRVGROUP
	TA_SUSPTIME
	TA_MINENCRYPTBITS
	TA_MAXDATALEN
	TA_DMOSITP
	TA_INTERN_DBBL
	TA_FORCEINIT
	TA_QCTL_REPLYQUEUE
	TA_DMLOGCONTENTIONS
	TA_SHM_NATTCH
	TA_MAXACLCACHE
	TA_MASTER
	TA_DMMAXRAPTRAN
	TA_GRPCOUNT
	TA_FRANGE
	TA_DMMAXSNASESS
	TA_MAXCURSORS
	TA_DMNETTRANID
	TA_JAVAHEAPSIZE
	TA_PROGMODELS
	TA_CURCLIENTS
	TA_APPQSPACERM
	TA_LASTGRP
	TA_FLOWCNT
	TA_DMRDOMSEC
	TA_DMAUTOTRAN
	TA_RESET
	TA_DMNWIDLETIME
	TA_ACCWORD
	TA_DMSSEL
	TA_OUTOFORDER
	TA_NUMBLOCKQ
	TA_CMDHW
	TA_CURSERVERS
	TA_MAXPROC
	TA_NUMSERVERS
	TA_DMRCONVTOTRCV
	TA_COORDSRVGRP
	TA_DMCREDENTIALPOLICY
	TA_SANITYSCAN
	TA_RQADDR
	TA_INTERN_TACTSRVGRP
	TA_CFGDEVICE
	TA_MAXDISPATCHTHREADS
	TA_CURMEMFILTERS
	TA_CLTNAME
	TA_DMTXTOTHCOMMIT
	TA_DMNUMREPRSVC
	TA_TPTRANID
	TA_CURGROUPS
	TA_JAVAHEAPUSE
	TA_DMRPRINPASSWD
	TA_TOTNQUEUED
	TA_HWHANDLERS
	TA_TLOGSIZE
	TA_MSGID
	TA_EXT_NADDR
	TA_NUMDEQUEUE
	TA_CMPLIMIT
	TA_DMURCH
	TA_CORRID
	TA_CONNOGRPNO
	TA_MAXRTDATA
	TA_NUMTRANCMT
	TA_HWMCONNUSED
	TA_IDLETIME
	TA_FLAGS
	TA_TIME
	TA_MEMOVERFLOW
	TA_PROPS
	TA_MAXACLGROUPS
	TA_CLASS
	TA_MAXHANDLERS
	TA_CFGOFFSET
	TA_NUMSERVED
	TA_GTRID
	TA_CURHANDLERS
	TA_SEVERITY
	TA_WAITTIMEOUT
	TA_TXPOLICY
	TA_COORDLMID
	TA_ULOGMSG
	TA_CURSOR
	TA_NRDOM
	TA_CURCONV
	TA_DMRCONVNUMACT
	TA_RELEASE
	TA_PRIORITY
	TA_HWINTERFACES
	TA_MEMSYSTEMRESERVED
	TA_MODULETYPE
	TA_WAITS
	TA_DMTSEL
	TA_CMDNONPERSIST
	TA_DMSTATRESETIME
	TA_CURWORK
	TA_APPQORDER
	TA_TLOGINDEX
	TA_CMD
	TA_CUROBJECTS
	TA_MAXGTT
	TA_EVENT_TRAN
	TA_DMBRANCHINDEX
	TA_DEVINDEX
	TA_SECURITY
	TA_LICSERIAL
	TA_MAXBUFSTYPE
	TA_CONNOPID
	TA_REPLYQ
	TA_ENC2_LPWD
	TA_FADDR
	TA_DMRSVCTOTFAIL
	TA_UID
	TA_MAXOWNERS
	TA_STATUS
	TA_DMTLOGDEV
	TA_DMNWDEVICE
	TA_TOTWORKL
	TA_EVENT_FILTER
	TA_HWTRANS
	TA_DMTAILORPATH
	TA_DMSTACKTYPE
	TA_DMSNASTACK
	TA_CURHANDLES
	TA_THREADSTACKSIZE
	TA_ROUTINGNAME
	TA_NADDR
	TA_DMRETRY_INTERVAL
	TA_LOOPBACK
	TA_CONNSSNDCNT
	TA_DMMAXRETRY
	TA_ITERATION
	TA_HWACTIONS
	TA_MAXSERVERS
	TA_SHRINKPERIOD
	TA_CURTRANS
	TA_DMLCONVTOTRCV
	TA_SHMID
	TA_CMDLW
	TA_TUXCONFIG
	TA_EVENT_UNIQUE
	TA_DMTUXOFFSET
	TA_PRIO
	TA_SIGNATURE_BEHIND
	TA_FREEMAPSIZE
	TA_WKINITIATED
	TA_BADFLD
	TA_NWADDRLEN
	TA_BLOB_SHM_SIZE
	TA_NETPRIO
	TA_RETRYDELAY
	TA_IPCKEY
	TA_DMNUMREQRSVC
	TA_CONNSLMID
	TA_NETGRPNO
	TA_HWGTT
	TA_DMNUMCONVACT
	TA_CLTREPLY
	TA_HWCURSORS
	TA_DMRANGES
	TA_HWMEMNONPERSIST
	TA_DMPRIORITY_TYPE
	TA_DMRCONVNUMRCV
	TA_ATTRIBUTE
	TA_QCTL_CORRID
	TA_ACLCACHEACCESS
	TA_NQUEUED
	TA_TOTWANTERS
	TA_DMNUMTXHCOMMIT
	TA_TOTACTTIME
	TA_DMSTATRESETTIME
	TA_TUXDIR
	TA_INTERN_TACTGRPNO
	TA_TYPE
	TA_FIELD
	TA_INTERN_FLDNAME
	TA_TIMEOUT
	TA_DMNUMCONVLSND
	TA_HWTMPQUEUES
	TA_CURBLOCKS
	TA_DMTE_QUALIFIER
	TA_DMAPI
	TA_DMMAXTRAN
	TA_INASTATES
	TA_FREEMAPAVAIL
	TA_RPID
	TA_DMRCONVTOT
	TA_INTERFACENAME
	TA_DMRDOMNUM
	TA_DMEVNUMACT
	TA_TRAN_STATE
	TA_DMAPT
	TA_DMNUMREQCOMP
	TA_DMLCONVNUMACT
	TA_SEC_PRINCIPAL_PASSVAR
	TA_DMTXTOTCOMMIT
	TA_STARTTIME
	TA_PRINCLTNAME
	TA_OLDCMPLIMIT
	TA_RCVDBYT
	TA_ULOGLINE
	TA_QCTL_FAILUREQUEUE
	TA_DMBRANCHSTATE
	TA_FILTER
	TA_JAVAVERSION
	TA_FREEMAPCOUNT
	TA_SENTBYT
	TA_SUBSCRIPTION_VERSION
	TA_INTERN_CURSOR
	TA_DMSECTYPE
	TA_AUTOTRAN
	TA_DMAPID
	TA_MAXOBJECTS
	TA_LICMAXUSERS
	TA_USERROLE
	TA_ACLNAME
	TA_SIGNATURE_REQUIRED
	TA_NUMSUBSCRIBE
	TA_ROLE
	TA_CURDRT
	TA_GID
	TA_DMNUMCONVLOC
	TA_DMTPNAME
	TA_DMLSVCTOTFAIL
	TA_TRANLEV
	TA_CURACTEV
	TA_CURSUSPNEV
	TA_MAXHANDLES
	TA_APPQMSGID
	TA_DBNAME
	TA_CONV2
	TA_DMCODEPAGE
	TA_EVENT_PERSIST
	TA_DMSHMCONTENTIONS
	TA_RQID
	TA_MSGEXPIRESTARTTIME
	TA_DMLCONV
	TA_DMEVNUMSUSPN
	TA_TMSNAME
	TA_ATTFLAGS
	TA_INTERN_APPKEY
	TA_CURTIME
	TA_QCTL_BEFOREMSGID
	TA_DMEVNUMSUSPT
	TA_CURINTERFACE
	TA_USRNAME
	TA_ACTIVE
	TA_NEWAPPQNAME
	TA_DBNETPROTOCOL
	TA_GRPINDEX
	TA_DMCONNPRINCIPALNAME
	TA_HWSERVICES
	TA_MIBMASK
	TA_MAXGROUPS
	TA_SWRELEASE
	TA_MAXNETGROUPS
	TA_DMLCONVNUMRCV
	TA_DMRPWD
	TA_GROUPNAME
	TA_HWCLIENTS
	TA_GETSTATES
	TA_TIMERESTART
	TA_DMTRANTIME
	TA_HWMEMFILTERS
	TA_CAPACITYINCR
	TA_MAXPERM
	TA_SVCRNAM
	TA_DMNUMCONVREM
	TA_EXPIRETIME
	TA_QSPACE
	TA_ON
	TA_COORDGRPNO
	TA_ENABLEXA
	TA_SETSTATES
	TA_LOAD
	TA_PERCENTINIT
	TA_XID
	TA_CMDNONPERSISTHW
	TA_HWSERVERS
	TA_VIEWREFRESH
	TA_MAXSERVICES
	TA_DMRSVCTOTRPLY
	TA_CURSERVICES
	TA_DMACLPOLICY
	TA_SERVICENAME
	TA_NETGROUP
	TA_HWQUEUES
	TA_NOTIFY
	TA_BLOCKTIME
	TA_SERVERCNT
	TA_DMRPRINNAME
	TA_ACLGROUPIDS
	TA_MINDISPATCHTHREADS
	TA_AUTOTRAN2
	TA_DMTE_RTQNAME
	TA_DMMAXRDTRAN
	TA_CURTRANSACTIONS
	TA_DUMMYOPTION
	TA_DMINPRIORITY
	TA_PRINPASSWD
	TA_WKQUEUED
	TA_ACLFAIL
	TA_DMMAXENCRYPTBITS
	TA_DMRSYSID
	TA_MODEL
	TA_MAXRFT
	TA_DMFIELD
	TA_EVENT_SERVER
	TA_TIMELEFT
	TA_HWACCESSERS
	TA_TMSCOUNT
	TA_DMMAXSYNCLVL
	TA_DEFAULT
	TA_RESTART
	TA_PRINID
	TA_MAX
	TA_INTERN_FLDTYPE
	TA_FREEMAPOFFSET
	TA_CONNOSNDCNT
	TA_SEMTICKET
	TA_DMTXTOTHRLBCK
	TA_CURTYPE
	TA_OPTIONS
	TA_DUMMYSRVGRP
	TA_HWMEMOVERFLOW
	TA_WSHNAME
	TA_MAXCAPACITY
	TA_QCTL_PRIORITY
	TA_MAXMTYPE
	TA_CLASSNAME
	TA_DSNAME
	TA_DMRESOURCENAME
	TA_DMNUMTXRLBCK
	TA_MAXENCRYPTBITS
	TA_HIGHPRIORITY
	TA_CLOSEINFO
	TA_SPINCOUNT
	TA_MSG_RTIME
	TA_DMTLOGNAME
	TA_DMLSYSID
	TA_HWOBJECTS
	TA_CONNSSRVID
	TA_DMTE_PRODUCT
	TA_NUMDISPATCHTHREADS
	TA_HWRFT
	TA_DMACCESSPOINT
	TA_DMFAILOVERSEQ
	TA_DMDIRECTION
	TA_ACLTYPE
	TA_DMOBUFSTYPE
	TA_URL
	TA_DMRCONVTOTSND
	TA_HWCONV
	TA_SRVTYPE
	TA_WSHCLIENTID
	TA_HWHANDLES
	TA_DMOBUFTYPE
	TA_CONNOREGIDX
	TA_DMBUFSTYPE
	TA_SIGNATURE_AHEAD
	TA_FIELDTYPE
	TA_LMID
	TA_DMLSVCTOTRPLY
	TA_DMTUXCONFIG
	TA_BLOCKING
	TA_CMDNONPERSISTLW
	TA_DMTE_RTQGROUP
	TA_LSTATE
	TA_MAXMSG
	TA_MAXTMPQUEUES
	TA_TMTRACE
	TA_FBROUTINGNAME
	TA_LOG_CONTENTIONS
	TA_SYSTEM_ACCESS
	TA_DMMODENAME
	TA_HWDISPATCHTHREADS
	TA_CURMEMOVERFLOW
	TA_HWRTDATA
	TA_APPQSPACENAME
	TA_DMNUMREPLSVC
	TA_RANGES
	TA_TOTREQC
	TA_DMACLNAME
	TA_DMNUMREQFAIL
	TA_DMTDOM
	TA_DMTXNETTRANID
	TA_DMOUTBUFTYPE
	TA_CLTLMID
	TA_SUSPENDED
	TA_DOMAINAME
	TA_ALLOWSHRINKING
	TA_GENERATION
	TA_MEMTOTALALLOCATED
	TA_BRIDGE
	TA_DMTE_TARGET
	TA_SICACHEENTRIESMAX
	TA_QMCONFIG
	TA_SHMSZ
	TA_KEEPALIVE
	TA_MAXPAGES
	TA_QCTL_QTOP
	TA_SHM_ATIME
	TA_CURGTT
	TA_DMROUTINGNAME
	TA_CONNSPID
	TA_BASESRVID
	TA_MULTIPLEX
	TA_RCMD
	TA_HWMSG
	TA_HWMFORWAIT
	TA_DBPORT
	TA_EVENT_SET_BLOB
	TA_MAXTRANS
	TA_OCCURS
	TA_REPLYPERSISTENCE
	TA_MAXIDLETIME
	TA_DUMMYALLSTATS
	TA_DMFUNCTION
	TA_FREEMAPINDEX
	TA_MSG_CTIME
	TA_INTERN_ERROR
	TA_DUMMYACTIVITY
	TA_QCTL_DEQ_TIME
	TA_HWOWNERS
	TA_CURPROC
	TA_INTERN_FLDVALUE
	TA_DMMINWIN
	TA_TRANTIME
	TA_DMAEID
	TA_FACTORYID
	TA_REENCRYPT_PWD
	TA_NUMCONV
	TA_DMCONV
	TA_MSG_STIME
	TA_CURRETRIES
	TA_DMTXID
	TA_SECURITY2
	TA_DUMMYTOGGLE
	TA_ULOGMSGNUM
	TA_DMLCONVTOTSND
	TA_DMTE_TP_SYSTEM
	TA_TOTNP
	TA_DMVERSION
	TA_EVENT_SET_HANDLE
	TA_TOTWKUPSENT
	TA_DMAUTOPREPARE
	TA_HWWSCLIENTS
	TA_TOTNV
	TA_COMMAND
	TA_EVENT_EXPR
	TA_DMLSVCTOT
	TA_DMSNALINK
	TA_APTLEN
	TA_QCTL_MSGID
	TA_MSG_QNUM
	TA_TMNETLOAD
	TA_DBBLWAIT
	TA_DMMAXRDOM
	TA_MAXINTERFACES
	TA_WSC
	TA_DMRCONVNUMSND
	TA_JAVAVENDOR
	TA_DEVICE
	TA_DMBLOB_SHM_SIZE
	TA_WSH
	TA_MODULEARGS
	TA_CURTMPQUEUES
	TA_TPPOLICY
	TA_DMREMTPSUT
	TA_DMNUMTXCOMMIT
	TA_PAGESIZE
	TA_GROUPID
	TA_MSGEXPIREENDTIME
	TA_DMRESOURCETYPE
	TA_MAXCONV
	TA_NUMTRANABT
	TA_DMRDOMUSR
	TA_DMNUMREQLSVC
	TA_SEM_OTIME
	TA_PRINGRP
	TA_DMOUTRECTYPE
	TA_MODULE
	TA_TLOGDEVICE
	TA_CURNONPERSISTBYTES
	TA_TESTTABLE
	TA_TOTWKUPRCV
	TA_WAITFORCONN
	TA_MAXEJBCACHE
	TA_DMPRINNAME
	TA_DMLUNAME
	TA_PERM
	TA_SEC_PRINCIPAL_NAME
	TA_DMOPTIONS
	TA_DMNUMTXBEGUN
	TA_MIBTIMEOUT
	TA_MAXGEN
	TA_DMSTARTTYPE
	TA_MAXACCESSERS
	TA_GRACE
	TA_CURSUSPTEV
	TA_MIN
	TA_LDOMAIN
	TA_MODULEFILE
	TA_QCTL_QTIME_ABS
	TA_ENCRYPTION_REQUIRED
	TA_DMBLOCKTIME
	TA_DMTE_FUNCTION
	TA_CURLMID
	TA_APPQNAME
	TA_DMRSVCNUMACT
	TA_TLOGNAME
	TA_DMTXACCESSPOINT
	TA_DMMAXLISTENINGEP
	TA_OFF
	TA_TLOGOFFSET
	TA_AWAITINGCONN
	TA_CONNOLMID
	TA_CREATEONSTARTUP
	TA_MAXRETRIES
	TA_CURACTRQ
	TA_LICEXPIRE
	TA_CURNONPERSISTMSG
	TA_DEBUG
	TA_GSTATE
	TA_NLSADDR
	TA_NUMENQUEUE
	TA_SRVID
	TA_MODULECLASSPATH
	TA_SVCTYPE
	TA_MSG_CBYTES
	TA_SOURCE
	TA_SHMKEY
	TA_DMCOUPLING
	TA_DMGWNUM
	TA_HWGROUPS
	TA_BUFTYPE
	TA_NUMUNSOL
	TA_CURQUEUES
	TA_DMSERVICENAME
	TA_ENC2_RPWD
	TA_MSGSTARTTIME
	TA_CURSORHOLD
	TA_DMRSVCTOT
	TA_BBLQUERY
	TA_CONNSGRPNO
	TA_DMINBUFTYPE
	TA_LOGINDELAY
	TA_DMLCONVNUMSND
	TA_ENVFILE
	TA_NCOMPLETED
	TA_SUBSCRIPTION_HANDLE
	TA_DMCONNECTION_POLICY
	TA_CURREQ
	TA_MAXPENDINGBYTES
	TA_MMDDYY
	TA_MINWSHPORT
	TA_DMBRANCHNO
	TA_PROFILE2
	TA_DMPSEL
	TA_ULOGPROCNM
	TA_DMLPWD
	TA_DMAUDIT
	TA_DMSTACKPARMS
	TA_CURRSERVICE
	TA_SEC_PRINCIPAL_PASSWORD
	TA_CONTEXT_ID
	TA_DMCURENCRYPTBITS
	TA_PASSWORD
	TA_DMTE_PWD
	TA_DUMMYSRVID
	TA_CURRFT
	TA_DMFIELDTYPE
	TA_DBPASSWORD
	TA_SHM_CTIME
	TA_BLOB_VALUE
	TA_OPENINFO
	TA_DMREMOTENAME
	TA_CONNUSED
	TA_DMLOCALPRINCIPALNAME
	TA_WKCOMPLETED
	TA_DMRDOMLIST
	TA_CLTPID
	TA_INITCAPACITY
	TA_DMPROFILE
	TA_DMNUMTXHRLBCK
	TA_MINOR
	TA_CURACCESSERS
	TA_DMTXPARENT
	TA_DMMACHINETYPE
	TA_RDOMAIN
	TA_EVENT_FILTER_BINARY
	TA_DMNUMCONVRSND
	TA_OPERATION
	TA_HWMCONNCREATED
	TA_PREFERENCES
	TA_DMOUTRECSTYPE
	TA_DMLACCESSPOINT
	TA_DEVSIZE
	TA_DMSYMDESTNAME
	TA_CURRLOAD
	TA_ACLCACHEHITS
	TA_CURSTYPE
	TA_USERLOG
	TA_DMEXTENSIONS
	TA_MSG_LRPID
	TA_CURENCRYPTBITS
	TA_MSGSIZE
	TA_DMACN
	TA_DBHOST
	TA_OLDENCRYPT
	TA_SCANUNIT
	TA_CONNOSRVID
	TA_PERSISTENCE
	TA_ENDTIME
	TA_HWMACHINES
	TA_DMAUDITLOG
	TA_DMPRIO
	TA_CLIENTID
	TA_SVCTIMEOUT
	TA_QCTL_QTIME_REL
	TA_DMTPTRANID
	TA_DMRACCESSPOINTLIST
	TA_ERRORQNAME
	TA_TIMESTART
	TA_PID
	TA_TLOGCOUNT
	TA_BLOB_TYPE
	TA_APPDIR
	TA_DMTXTOTRLBCK
	TA_MAXWSCLIENTS
	TA_DMTLOGSIZE
	TA_CLASSPATH
	TA_DMINRECTYPE
	TA_DBUSER
	TA_DMLCONVTOTFAIL
	TA_DMBRANCHCOUNT
	TA_MAXINITTIME
	TA_PMID
	TA_CURRTDATA
	TA_VALIDATION
	TA_MSGENDTIME
	TA_MAXMACHINES
	TA_CURINTERFACES
	TA_CONNAVAILABLE
	TA_REFRESH
	TA_CONTIME
	TA_DMCMPLIMIT
	TA_CURMSG
	TA_QNAME
	TA_CURMACHINES
	TA_DMTYPE
	TA_HITICKET
	TA_MINHANDLERS
	TA_RPPERM
	TA_SEQUENCE
	TA_PRINNAME
	TA_CURACTIONS
	TA_DMRACCESSPOINT
	TA_RCVDNUM
	TA_TOTIDLTIME
	TA_DOMAINID
	TA_DMNETID
	TA_TUXOFFSET
	TA_TMDEBUG
	TA_DMAEQ
	TA_SENTNUM
	TA_ERROR
	TA_DMAET
	TA_NETTIMEOUT
	TA_MAXDRT
	TA_DMNWADDR
	TA_SEMID
	TA_FACTPERM
	TA_DMTPSUTTYPE
	TA_DMMULTIPLEXING
	TA_HWPROC
	TA_DMSNADOM
	TA_SHM_DTIME
	TA_DMXATMIENCODING
	TA_CURCURSORS
	TA_MSG_QBYTES
	TA_STATE
	TA_MSG_LSPID
	TA_CLOPT
	TA_CUREXTENT
	TA_DMTXNUMACT
	TA_ULOGPFX
	TA_CUROWNERS
	TA_DMSECURITY
	TA_DMLCONVTOT
	TA_DRIVER
	TA_DMRCONVTOTFAIL
	TA_ULOGCAT
	TA_CMTRET
	TA_DMSNACRM
	TA_CONV
	TA_AEQLEN
	TA_SERVERNAME
	TA_DMACCESSPOINTID
	TA_DUMMYDOMSTATS
	TA_DMSTATISTICS
	TA_MAXWSHPORT
	TA_TESTONRELEASE
	TA_WSPROTO
	TA_INTERN_TACTSRVID
	TA_ACN2
	TA_NUMTRAN
	TA_CURDISPATCHTHREADS
	TA_ENCPASSWD
	TA_HWDRT
	TA_DMDNSRESOLUTION
	TA_MAXQUEUELEN
);

# subs
sub TA_DMMINENCRYPTBITS { 167779061; }
sub TA_DMBUFTYPE { 167778977; }
sub TA_TLOGDATA { 167778561; }
sub TA_CONTEXTID { 33560958; }
sub TA_USIGNAL { 167778595; }
sub TA_MEMNONPERSIST { 167778835; }
sub TA_LOWPRIORITY { 33561054; }
sub TA_NUMPOST { 33560772; }
sub TA_SHM_CONTENTIONS { 33561303; }
sub TA_CURMEMNONPERSIST { 33561089; }
sub TA_MAXQUEUES { 33560744; }
sub TA_AUTHSVC { 167778362; }
sub TA_LDBAL { 167778455; }
sub TA_DEFEXPIRATIONTIME { 167778807; }
sub TA_TOTWKQUEUED { 33560848; }
sub TA_DEFDELIVERYPOLICY { 167778806; }
sub TA_HWACLCACHE { 33560892; }
sub TA_SRVGRP { 167778862; }
sub TA_THREADID { 33560957; }
sub TA_MAXBUFTYPE { 33560736; }
sub TA_EJBCACHE_FLUSH { 63555454; }
sub TA_COMPONENTS { 167778656; }
sub TA_ULOGTIME { 33560866; }
sub TA_GRPNO { 33560707; }
sub TA_DEVOFFSET { 33560690; }
sub TA_CURWSCLIENTS { 33560685; }
sub TA_DUMMYSTATE { 6837; }
sub TA_MAXSENDLEN { 33561238; }
sub TA_DMLSVCNUMACT { 63555960; }
sub TA_DMLOAD { 6832; }
sub TA_PASSWD { 167779035; }
sub TA_MORE { 33560442; }
sub TA_SEC_PRINCIPAL_LOCATION { 167778694; }
sub TA_DMINRECSTYPE { 167779090; }
sub TA_MAXACTIONS { 33561101; }
sub TA_RQPERM { 33560800; }
sub TA_MEMFILTERS { 33561106; }
sub TA_NUMREQ { 33560773; }
sub TA_TESTONRESERVE { 197773242; }
sub TA_DMSRVGROUP { 167778954; }
sub TA_SUSPTIME { 33560823; }
sub TA_MINENCRYPTBITS { 167778652; }
sub TA_MAXDATALEN { 33561234; }
sub TA_DMOSITP { 167778940; }
sub TA_INTERN_DBBL { 63555456; }
sub TA_FORCEINIT { 167778777; }
sub TA_QCTL_REPLYQUEUE { 167779124; }
sub TA_DMLOGCONTENTIONS { 63555964; }
sub TA_SHM_NATTCH { 33560820; }
sub TA_MAXACLCACHE { 33560896; }
sub TA_MASTER { 167778460; }
sub TA_DMMAXRAPTRAN { 30001514; }
sub TA_GRPCOUNT { 33560705; }
sub TA_FRANGE { 33560970; }
sub TA_DMMAXSNASESS { 6766; }
sub TA_MAXCURSORS { 33561102; }
sub TA_DMNETTRANID { 197773721; }
sub TA_JAVAHEAPSIZE { 63555436; }
sub TA_PROGMODELS { 197773162; }
sub TA_CURCLIENTS { 33560667; }
sub TA_APPQSPACERM { 167778764; }
sub TA_LASTGRP { 33560726; }
sub TA_FLOWCNT { 33560696; }
sub TA_DMRDOMSEC { 167779057; }
sub TA_DMAUTOTRAN { 167778988; }
sub TA_RESET { 6844; }
sub TA_DMNWIDLETIME { 33561211; }
sub TA_ACCWORD { 33560632; }
sub TA_DMSSEL { 167779083; }
sub TA_OUTOFORDER { 167778793; }
sub TA_NUMBLOCKQ { 33560904; }
sub TA_CMDHW { 167778767; }
sub TA_CURSERVERS { 33560680; }
sub TA_MAXPROC { 33561058; }
sub TA_NUMSERVERS { 33560944; }
sub TA_DMRCONVTOTRCV { 63555970; }
sub TA_COORDSRVGRP { 167778649; }
sub TA_DMCREDENTIALPOLICY { 197773731; }
sub TA_SANITYSCAN { 33560801; }
sub TA_RQADDR { 167778526; }
sub TA_INTERN_TACTSRVGRP { 197773174; }
sub TA_CFGDEVICE { 167778369; }
sub TA_MAXDISPATCHTHREADS { 33560959; }
sub TA_CURMEMFILTERS { 33561088; }
sub TA_CLTNAME { 167778375; }
sub TA_DMTXTOTHCOMMIT { 63555980; }
sub TA_DMNUMREPRSVC { 33561285; }
sub TA_TPTRANID { 167778580; }
sub TA_CURGROUPS { 33560670; }
sub TA_JAVAHEAPUSE { 63555438; }
sub TA_DMRPRINPASSWD { 167779055; }
sub TA_TOTNQUEUED { 33560844; }
sub TA_HWHANDLERS { 33560893; }
sub TA_TLOGSIZE { 33560838; }
sub TA_MSGID { 33560755; }
sub TA_EXT_NADDR { 167778655; }
sub TA_NUMDEQUEUE { 33560770; }
sub TA_CMPLIMIT { 167778378; }
sub TA_DMURCH { 167778952; }
sub TA_CORRID { 167778769; }
sub TA_CONNOGRPNO { 33560652; }
sub TA_MAXRTDATA { 33560746; }
sub TA_NUMTRANCMT { 33560779; }
sub TA_HWMCONNUSED { 63555520; }
sub TA_IDLETIME { 33560894; }
sub TA_FLAGS { 33560440; }
sub TA_TIME { 167778799; }
sub TA_MEMOVERFLOW { 33561108; }
sub TA_PROPS { 197773232; }
sub TA_MAXACLGROUPS { 33560897; }
sub TA_CLASS { 167778162; }
sub TA_MAXHANDLERS { 33560898; }
sub TA_CFGOFFSET { 33560642; }
sub TA_NUMSERVED { 33560775; }
sub TA_GTRID { 167778437; }
sub TA_CURHANDLERS { 33560885; }
sub TA_SEVERITY { 167778541; }
sub TA_WAITTIMEOUT { 63555517; }
sub TA_TXPOLICY { 167778674; }
sub TA_COORDLMID { 167778393; }
sub TA_ULOGMSG { 167778590; }
sub TA_CURSOR { 167778164; }
sub TA_NRDOM { 6815; }
sub TA_CURCONV { 33560668; }
sub TA_DMRCONVNUMACT { 63555965; }
sub TA_RELEASE { 33560791; }
sub TA_PRIORITY { 33561067; }
sub TA_HWINTERFACES { 33560950; }
sub TA_MEMSYSTEMRESERVED { 33561109; }
sub TA_MODULETYPE { 197773204; }
sub TA_WAITS { 167778598; }
sub TA_DMTSEL { 167779080; }
sub TA_CMDNONPERSIST { 167778801; }
sub TA_DMSTATRESETIME { 33561302; }
sub TA_CURWORK { 33560886; }
sub TA_APPQORDER { 167778762; }
sub TA_TLOGINDEX { 33560835; }
sub TA_CMD { 167778766; }
sub TA_CUROBJECTS { 33560939; }
sub TA_MAXGTT { 33560741; }
sub TA_EVENT_TRAN { 6967; }
sub TA_DMBRANCHINDEX { 63555990; }
sub TA_DEVINDEX { 33560689; }
sub TA_SECURITY { 167778531; }
sub TA_LICSERIAL { 167778458; }
sub TA_MAXBUFSTYPE { 33560735; }
sub TA_CONNOPID { 33560654; }
sub TA_REPLYQ { 167778520; }
sub TA_ENC2_LPWD { 167779039; }
sub TA_FADDR { 167778697; }
sub TA_DMRSVCTOTFAIL { 63555974; }
sub TA_UID { 33560859; }
sub TA_MAXOWNERS { 33561104; }
sub TA_STATUS { 167778175; }
sub TA_DMTLOGDEV { 167778957; }
sub TA_DMNWDEVICE { 167778938; }
sub TA_TOTWORKL { 33560851; }
sub TA_EVENT_FILTER { 167779112; }
sub TA_HWTRANS { 33561053; }
sub TA_DMTAILORPATH { 167779081; }
sub TA_DMSTACKTYPE { 167779070; }
sub TA_DMSNASTACK { 167779068; }
sub TA_CURHANDLES { 33561087; }
sub TA_THREADSTACKSIZE { 33560961; }
sub TA_ROUTINGNAME { 167778523; }
sub TA_NADDR { 167778492; }
sub TA_DMRETRY_INTERVAL { 33561350; }
sub TA_LOOPBACK { 6813; }
sub TA_CONNSSNDCNT { 33560661; }
sub TA_DMMAXRETRY { 33561351; }
sub TA_ITERATION { 33560725; }
sub TA_HWACTIONS { 33561093; }
sub TA_MAXSERVERS { 33560747; }
sub TA_SHRINKPERIOD { 63555511; }
sub TA_CURTRANS { 33561047; }
sub TA_DMLCONVTOTRCV { 63555958; }
sub TA_SHMID { 33560814; }
sub TA_CMDLW { 167778768; }
sub TA_TUXCONFIG { 167778583; }
sub TA_EVENT_UNIQUE { 6976; }
sub TA_DMTUXOFFSET { 33561242; }
sub TA_PRIO { 33560786; }
sub TA_SIGNATURE_BEHIND { 33560954; }
sub TA_FREEMAPSIZE { 33560701; }
sub TA_WKINITIATED { 33560872; }
sub TA_BADFLD { 33560433; }
sub TA_NWADDRLEN { 6777; }
sub TA_BLOB_SHM_SIZE { 33561243; }
sub TA_NETPRIO { 33560934; }
sub TA_RETRYDELAY { 33561069; }
sub TA_IPCKEY { 33560724; }
sub TA_DMNUMREQRSVC { 33561283; }
sub TA_CONNSLMID { 167778387; }
sub TA_NETGRPNO { 33560933; }
sub TA_HWGTT { 33560716; }
sub TA_DMNUMCONVACT { 33561289; }
sub TA_CLTREPLY { 167778377; }
sub TA_HWCURSORS { 33561094; }
sub TA_DMRANGES { 167778987; }
sub TA_HWMEMNONPERSIST { 33561097; }
sub TA_DMPRIORITY_TYPE { 197773729; }
sub TA_DMRCONVNUMRCV { 63555966; }
sub TA_ATTRIBUTE { 33560432; }
sub TA_QCTL_CORRID { 167779123; }
sub TA_ACLCACHEACCESS { 33560877; }
sub TA_NQUEUED { 33560768; }
sub TA_TOTWANTERS { 33560847; }
sub TA_DMNUMTXHCOMMIT { 33561299; }
sub TA_TOTACTTIME { 33560914; }
sub TA_DMSTATRESETTIME { 63555977; }
sub TA_TUXDIR { 167778584; }
sub TA_INTERN_TACTGRPNO { 63555447; }
sub TA_TYPE { 167778586; }
sub TA_FIELD { 167778423; }
sub TA_INTERN_FLDNAME { 197773177; }
sub TA_TIMEOUT { 33560829; }
sub TA_DMNUMCONVLSND { 33561291; }
sub TA_HWTMPQUEUES { 33561100; }
sub TA_CURBLOCKS { 33561042; }
sub TA_DMTE_QUALIFIER { 63555942; }
sub TA_DMAPI { 167779073; }
sub TA_DMMAXTRAN { 6805; }
sub TA_INASTATES { 167778623; }
sub TA_FREEMAPAVAIL { 33560697; }
sub TA_RPID { 33560796; }
sub TA_DMRCONVTOT { 63555968; }
sub TA_INTERFACENAME { 167778669; }
sub TA_DMRDOMNUM { 33561315; }
sub TA_DMEVNUMACT { 63555950; }
sub TA_TRAN_STATE { 33561280; }
sub TA_DMAPT { 167778941; }
sub TA_DMNUMREQCOMP { 33561287; }
sub TA_DMLCONVNUMACT { 63555953; }
sub TA_SEC_PRINCIPAL_PASSVAR { 167778695; }
sub TA_DMTXTOTCOMMIT { 63555979; }
sub TA_STARTTIME { 167778798; }
sub TA_PRINCLTNAME { 167778634; }
sub TA_OLDCMPLIMIT { 167778658; }
sub TA_RCVDBYT { 33560789; }
sub TA_ULOGLINE { 33560861; }
sub TA_QCTL_FAILUREQUEUE { 167779125; }
sub TA_DMBRANCHSTATE { 197773720; }
sub TA_FILTER { 33560439; }
sub TA_JAVAVERSION { 197773171; }
sub TA_FREEMAPCOUNT { 33560698; }
sub TA_SENTBYT { 33560807; }
sub TA_SUBSCRIPTION_VERSION { 33561403; }
sub TA_INTERN_CURSOR { 63555448; }
sub TA_DMSECTYPE { 167778924; }
sub TA_AUTOTRAN { 167778363; }
sub TA_DMAPID { 6788; }
sub TA_MAXOBJECTS { 33560943; }
sub TA_LICMAXUSERS { 33560729; }
sub TA_USERROLE { 197773253; }
sub TA_ACLNAME { 167778609; }
sub TA_SIGNATURE_REQUIRED { 167778683; }
sub TA_NUMSUBSCRIBE { 33560776; }
sub TA_ROLE { 167778522; }
sub TA_CURDRT { 33560669; }
sub TA_GID { 33560703; }
sub TA_DMNUMCONVLOC { 33561290; }
sub TA_DMTPNAME { 167779071; }
sub TA_DMLSVCTOTFAIL { 63555962; }
sub TA_TRANLEV { 33560853; }
sub TA_CURACTEV { 33561294; }
sub TA_CURSUSPNEV { 33561296; }
sub TA_MAXHANDLES { 33561103; }
sub TA_APPQMSGID { 167778760; }
sub TA_DBNAME { 197773225; }
sub TA_CONV2 { 6831; }
sub TA_DMCODEPAGE { 167779075; }
sub TA_EVENT_PERSIST { 6966; }
sub TA_DMSHMCONTENTIONS { 63555976; }
sub TA_RQID { 33560799; }
sub TA_MSGEXPIRESTARTTIME { 167778810; }
sub TA_DMLCONV { 167778927; }
sub TA_DMEVNUMSUSPN { 63555951; }
sub TA_TMSNAME { 167778570; }
sub TA_ATTFLAGS { 33560884; }
sub TA_INTERN_APPKEY { 63555452; }
sub TA_CURTIME { 33560683; }
sub TA_QCTL_BEFOREMSGID { 6959; }
sub TA_DMEVNUMSUSPT { 63555952; }
sub TA_CURINTERFACE { 167778666; }
sub TA_USRNAME { 167778596; }
sub TA_ACTIVE { 167778611; }
sub TA_NEWAPPQNAME { 167778792; }
sub TA_DBNETPROTOCOL { 197773230; }
sub TA_GRPINDEX { 33560706; }
sub TA_DMCONNPRINCIPALNAME { 197773726; }
sub TA_HWSERVICES { 33560722; }
sub TA_MIBMASK { 33560750; }
sub TA_MAXGROUPS { 33560740; }
sub TA_SWRELEASE { 167778554; }
sub TA_MAXNETGROUPS { 33560935; }
sub TA_DMLCONVNUMRCV { 63555954; }
sub TA_DMRPWD { 167779038; }
sub TA_GROUPNAME { 167778619; }
sub TA_HWCLIENTS { 33560712; }
sub TA_GETSTATES { 167778617; }
sub TA_TIMERESTART { 33560830; }
sub TA_DMTRANTIME { 33561266; }
sub TA_HWMEMFILTERS { 33561096; }
sub TA_CAPACITYINCR { 63555510; }
sub TA_MAXPERM { 33560901; }
sub TA_SVCRNAM { 167778552; }
sub TA_DMNUMCONVREM { 33561292; }
sub TA_EXPIRETIME { 167778808; }
sub TA_QSPACE { 167779114; }
sub TA_ON { 6842; }
sub TA_COORDGRPNO { 33560920; }
sub TA_ENABLEXA { 197773233; }
sub TA_SETSTATES { 167778639; }
sub TA_LOAD { 33560731; }
sub TA_PERCENTINIT { 33561066; }
sub TA_XID { 167778604; }
sub TA_CMDNONPERSISTHW { 167778802; }
sub TA_HWSERVERS { 33560721; }
sub TA_VIEWREFRESH { 167778644; }
sub TA_MAXSERVICES { 33560748; }
sub TA_DMRSVCTOTRPLY { 63555975; }
sub TA_CURSERVICES { 33560681; }
sub TA_DMACLPOLICY { 197773725; }
sub TA_SERVICENAME { 167778540; }
sub TA_NETGROUP { 167778660; }
sub TA_HWQUEUES { 33560718; }
sub TA_NOTIFY { 167778495; }
sub TA_BLOCKTIME { 33560638; }
sub TA_SERVERCNT { 33560810; }
sub TA_DMRPRINNAME { 167779054; }
sub TA_ACLGROUPIDS { 167778608; }
sub TA_MINDISPATCHTHREADS { 33560960; }
sub TA_AUTOTRAN2 { 6829; }
sub TA_DMTE_RTQNAME { 197773672; }
sub TA_DMMAXRDTRAN { 6804; }
sub TA_CURTRANSACTIONS { 33560940; }
sub TA_DUMMYOPTION { 6841; }
sub TA_DMINPRIORITY { 30001570; }
sub TA_PRINPASSWD { 167778638; }
sub TA_WKQUEUED { 33560873; }
sub TA_ACLFAIL { 33560879; }
sub TA_DMMAXENCRYPTBITS { 167779062; }
sub TA_DMRSYSID { 167779065; }
sub TA_MODEL { 167778482; }
sub TA_MAXRFT { 33560745; }
sub TA_DMFIELD { 167778986; }
sub TA_EVENT_SERVER { 167779130; }
sub TA_TIMELEFT { 33560828; }
sub TA_HWACCESSERS { 33560711; }
sub TA_TMSCOUNT { 33560841; }
sub TA_DMMAXSYNCLVL { 6907; }
sub TA_DEFAULT { 167778615; }
sub TA_RESTART { 167778521; }
sub TA_PRINID { 33560908; }
sub TA_MAX { 33560733; }
sub TA_INTERN_FLDTYPE { 63555451; }
sub TA_FREEMAPOFFSET { 33560700; }
sub TA_CONNOSNDCNT { 33560656; }
sub TA_SEMTICKET { 33560805; }
sub TA_DMTXTOTHRLBCK { 63555981; }
sub TA_CURTYPE { 33560684; }
sub TA_OPTIONS { 167778510; }
sub TA_DUMMYSRVGRP { 167778995; }
sub TA_HWMEMOVERFLOW { 33561098; }
sub TA_WSHNAME { 167778646; }
sub TA_MAXCAPACITY { 63555509; }
sub TA_QCTL_PRIORITY { 33561393; }
sub TA_MAXMTYPE { 33560743; }
sub TA_CLASSNAME { 167778163; }
sub TA_DSNAME { 197773222; }
sub TA_DMRESOURCENAME { 197773665; }
sub TA_DMNUMTXRLBCK { 33561301; }
sub TA_MAXENCRYPTBITS { 167778653; }
sub TA_HIGHPRIORITY { 33561050; }
sub TA_CLOSEINFO { 167778373; }
sub TA_SPINCOUNT { 33560822; }
sub TA_MSG_RTIME { 33560762; }
sub TA_DMTLOGNAME { 167778960; }
sub TA_DMLSYSID { 167779064; }
sub TA_HWOBJECTS { 33560947; }
sub TA_CONNSSRVID { 33560662; }
sub TA_DMTE_PRODUCT { 197773667; }
sub TA_NUMDISPATCHTHREADS { 33560964; }
sub TA_HWRFT { 33560719; }
sub TA_DMACCESSPOINT { 197773661; }
sub TA_DMFAILOVERSEQ { 30001551; }
sub TA_DMDIRECTION { 167779056; }
sub TA_ACLTYPE { 167778610; }
sub TA_DMOBUFSTYPE { 167778981; }
sub TA_URL { 197773224; }
sub TA_DMRCONVTOTSND { 63555971; }
sub TA_HWCONV { 33560713; }
sub TA_SRVTYPE { 197773163; }
sub TA_WSHCLIENTID { 167778645; }
sub TA_HWHANDLES { 33561095; }
sub TA_DMOBUFTYPE { 167778980; }
sub TA_CONNOREGIDX { 33560655; }
sub TA_DMBUFSTYPE { 167778978; }
sub TA_SIGNATURE_AHEAD { 33560953; }
sub TA_FIELDTYPE { 167778680; }
sub TA_LMID { 167778860; }
sub TA_DMLSVCTOTRPLY { 63555963; }
sub TA_DMTUXCONFIG { 167778969; }
sub TA_BLOCKING { 33561037; }
sub TA_CMDNONPERSISTLW { 167778803; }
sub TA_DMTE_RTQGROUP { 197773671; }
sub TA_LSTATE { 167778783; }
sub TA_MAXMSG { 33561056; }
sub TA_MAXTMPQUEUES { 33561105; }
sub TA_TMTRACE { 167778864; }
sub TA_FBROUTINGNAME { 167778676; }
sub TA_LOG_CONTENTIONS { 33561304; }
sub TA_SYSTEM_ACCESS { 167778555; }
sub TA_DMMODENAME { 167778922; }
sub TA_HWDISPATCHTHREADS { 33560963; }
sub TA_CURMEMOVERFLOW { 33561090; }
sub TA_HWRTDATA { 33560720; }
sub TA_APPQSPACENAME { 167778763; }
sub TA_DMNUMREPLSVC { 33561284; }
sub TA_RANGES { 201332947; }
sub TA_TOTREQC { 33560846; }
sub TA_DMACLNAME { 167778974; }
sub TA_DMNUMREQFAIL { 33561288; }
sub TA_DMTDOM { 167778935; }
sub TA_DMTXNETTRANID { 197773716; }
sub TA_DMOUTBUFTYPE { 167778982; }
sub TA_CLTLMID { 167778374; }
sub TA_SUSPENDED { 167778640; }
sub TA_DOMAINAME { 167778956; }
sub TA_ALLOWSHRINKING { 197773252; }
sub TA_GENERATION { 33560702; }
sub TA_MEMTOTALALLOCATED { 33561110; }
sub TA_BRIDGE { 167778367; }
sub TA_DMTE_TARGET { 197773669; }
sub TA_SICACHEENTRIESMAX { 167778699; }
sub TA_QMCONFIG { 167778796; }
sub TA_SHMSZ { 33560816; }
sub TA_KEEPALIVE { 167778664; }
sub TA_MAXPAGES { 33561057; }
sub TA_QCTL_QTOP { 6958; }
sub TA_SHM_ATIME { 33560817; }
sub TA_CURGTT { 33560671; }
sub TA_DMROUTINGNAME { 167778985; }
sub TA_CONNSPID { 33560660; }
sub TA_BASESRVID { 33560636; }
sub TA_MULTIPLEX { 33560903; }
sub TA_RCMD { 167778516; }
sub TA_HWMSG { 33561051; }
sub TA_HWMFORWAIT { 63555523; }
sub TA_DBPORT { 63555503; }
sub TA_EVENT_SET_BLOB { 6975; }
sub TA_MAXTRANS { 33561060; }
sub TA_OCCURS { 33560443; }
sub TA_REPLYPERSISTENCE { 167778812; }
sub TA_MAXIDLETIME { 33560899; }
sub TA_DUMMYALLSTATS { 6839; }
sub TA_DMFUNCTION { 167779074; }
sub TA_FREEMAPINDEX { 33560699; }
sub TA_MSG_CTIME { 33560757; }
sub TA_INTERN_ERROR { 63555455; }
sub TA_DUMMYACTIVITY { 6838; }
sub TA_QCTL_DEQ_TIME { 33561392; }
sub TA_HWOWNERS { 33561099; }
sub TA_CURPROC { 33561045; }
sub TA_INTERN_FLDVALUE { 197773178; }
sub TA_DMMINWIN { 6906; }
sub TA_TRANTIME { 33560854; }
sub TA_DMAEID { 6789; }
sub TA_FACTORYID { 167778679; }
sub TA_REENCRYPT_PWD { 6881; }
sub TA_NUMCONV { 33560769; }
sub TA_DMCONV { 167778990; }
sub TA_MSG_STIME { 33560763; }
sub TA_CURRETRIES { 33561046; }
sub TA_DMTXID { 167779045; }
sub TA_SECURITY2 { 6808; }
sub TA_DUMMYTOGGLE { 6845; }
sub TA_ULOGMSGNUM { 33560863; }
sub TA_DMLCONVTOTSND { 63555959; }
sub TA_DMTE_TP_SYSTEM { 197773673; }
sub TA_TOTNP { 33560843; }
sub TA_DMVERSION { 197773677; }
sub TA_EVENT_SET_HANDLE { 6974; }
sub TA_TOTWKUPSENT { 33560850; }
sub TA_DMAUTOPREPARE { 167779093; }
sub TA_HWWSCLIENTS { 33560723; }
sub TA_TOTNV { 33560845; }
sub TA_COMMAND { 167779129; }
sub TA_EVENT_EXPR { 167779111; }
sub TA_DMLSVCTOT { 63555961; }
sub TA_DMSNALINK { 167779063; }
sub TA_APTLEN { 6782; }
sub TA_QCTL_MSGID { 167779122; }
sub TA_MSG_QNUM { 33560761; }
sub TA_TMNETLOAD { 33560840; }
sub TA_DBBLWAIT { 33560686; }
sub TA_DMMAXRDOM { 33561235; }
sub TA_MAXINTERFACES { 33560942; }
sub TA_WSC { 167778602; }
sub TA_DMRCONVNUMSND { 63555967; }
sub TA_JAVAVENDOR { 197773172; }
sub TA_DEVICE { 167778416; }
sub TA_DMBLOB_SHM_SIZE { 63555985; }
sub TA_WSH { 167778603; }
sub TA_MODULEARGS { 197773203; }
sub TA_CURTMPQUEUES { 33561092; }
sub TA_TPPOLICY { 167778673; }
sub TA_DMREMTPSUT { 167779095; }
sub TA_DMNUMTXCOMMIT { 33561298; }
sub TA_PAGESIZE { 33560783; }
sub TA_GROUPID { 33560890; }
sub TA_MSGEXPIREENDTIME { 167778809; }
sub TA_DMRESOURCETYPE { 197773666; }
sub TA_MAXCONV { 33560737; }
sub TA_NUMTRANABT { 33560778; }
sub TA_DMRDOMUSR { 167779058; }
sub TA_DMNUMREQLSVC { 33561282; }
sub TA_SEM_OTIME { 33560806; }
sub TA_PRINGRP { 33560907; }
sub TA_DMOUTRECTYPE { 167779091; }
sub TA_MODULE { 197773202; }
sub TA_TLOGDEVICE { 167778562; }
sub TA_CURNONPERSISTBYTES { 33561076; }
sub TA_TESTTABLE { 197773240; }
sub TA_TOTWKUPRCV { 33560849; }
sub TA_WAITFORCONN { 197773244; }
sub TA_MAXEJBCACHE { 63555453; }
sub TA_DMPRINNAME { 167779053; }
sub TA_DMLUNAME { 167778921; }
sub TA_PERM { 33560445; }
sub TA_SEC_PRINCIPAL_NAME { 167778693; }
sub TA_DMOPTIONS { 167779087; }
sub TA_DMNUMTXBEGUN { 33561297; }
sub TA_MIBTIMEOUT { 33560441; }
sub TA_MAXGEN { 33560739; }
sub TA_DMSTARTTYPE { 167779076; }
sub TA_MAXACCESSERS { 33560734; }
sub TA_GRACE { 33560704; }
sub TA_CURSUSPTEV { 33561295; }
sub TA_MIN { 33560751; }
sub TA_LDOMAIN { 167778953; }
sub TA_MODULEFILE { 197773205; }
sub TA_QCTL_QTIME_ABS { 6956; }
sub TA_ENCRYPTION_REQUIRED { 167778684; }
sub TA_DMBLOCKTIME { 6799; }
sub TA_DMTE_FUNCTION { 197773668; }
sub TA_CURLMID { 167778400; }
sub TA_APPQNAME { 167778761; }
sub TA_DMRSVCNUMACT { 63555972; }
sub TA_TLOGNAME { 167778564; }
sub TA_DMTXACCESSPOINT { 197773715; }
sub TA_DMMAXLISTENINGEP { 30001516; }
sub TA_OFF { 6843; }
sub TA_TLOGOFFSET { 33560837; }
sub TA_AWAITINGCONN { 63555522; }
sub TA_CONNOLMID { 167778381; }
sub TA_CREATEONSTARTUP { 197773234; }
sub TA_MAXRETRIES { 33561059; }
sub TA_CURACTRQ { 33561286; }
sub TA_LICEXPIRE { 167778456; }
sub TA_CURNONPERSISTMSG { 33561077; }
sub TA_DEBUG { 167778415; }
sub TA_GSTATE { 167778436; }
sub TA_NLSADDR { 167778494; }
sub TA_NUMENQUEUE { 33560771; }
sub TA_SRVID { 33561135; }
sub TA_MODULECLASSPATH { 197773206; }
sub TA_SVCTYPE { 167778641; }
sub TA_MSG_CBYTES { 33560756; }
sub TA_SOURCE { 167778549; }
sub TA_SHMKEY { 33560815; }
sub TA_DMCOUPLING { 167779088; }
sub TA_DMGWNUM { 33561314; }
sub TA_HWGROUPS { 33560715; }
sub TA_BUFTYPE { 167778368; }
sub TA_NUMUNSOL { 33560780; }
sub TA_CURQUEUES { 33560674; }
sub TA_DMSERVICENAME { 167778984; }
sub TA_ENC2_RPWD { 167779040; }
sub TA_MSGSTARTTIME { 167778791; }
sub TA_CURSORHOLD { 33560437; }
sub TA_DMRSVCTOT { 63555973; }
sub TA_BBLQUERY { 33560637; }
sub TA_CONNSGRPNO { 33560658; }
sub TA_DMINBUFTYPE { 167778979; }
sub TA_LOGINDELAY { 63555507; }
sub TA_DMLCONVNUMSND { 63555955; }
sub TA_ENVFILE { 167778422; }
sub TA_NCOMPLETED { 33560765; }
sub TA_SUBSCRIPTION_HANDLE { 33561439; }
sub TA_DMCONNECTION_POLICY { 167779077; }
sub TA_CURREQ { 33560675; }
sub TA_MAXPENDINGBYTES { 33560931; }
sub TA_MMDDYY { 33560753; }
sub TA_MINWSHPORT { 33560922; }
sub TA_DMBRANCHNO { 63555991; }
sub TA_PROFILE2 { 6791; }
sub TA_DMPSEL { 167779082; }
sub TA_ULOGPROCNM { 167778593; }
sub TA_DMLPWD { 167779037; }
sub TA_DMAUDIT { 6847; }
sub TA_DMSTACKPARMS { 167779072; }
sub TA_CURRSERVICE { 167778406; }
sub TA_SEC_PRINCIPAL_PASSWORD { 167778696; }
sub TA_CONTEXT_ID { 33561072; }
sub TA_DMCURENCRYPTBITS { 197773723; }
sub TA_PASSWORD { 167778861; }
sub TA_DMTE_PWD { 197773712; }
sub TA_DUMMYSRVID { 6836; }
sub TA_CURRFT { 33560676; }
sub TA_DMFIELDTYPE { 197773724; }
sub TA_DBPASSWORD { 197773227; }
sub TA_SHM_CTIME { 33560818; }
sub TA_BLOB_VALUE { 201333565; }
sub TA_OPENINFO { 167778509; }
sub TA_DMREMOTENAME { 167778983; }
sub TA_CONNUSED { 63555518; }
sub TA_DMLOCALPRINCIPALNAME { 197773727; }
sub TA_WKCOMPLETED { 33560871; }
sub TA_DMRDOMLIST { 167778976; }
sub TA_CLTPID { 33560648; }
sub TA_INITCAPACITY { 63555508; }
sub TA_DMPROFILE { 167778950; }
sub TA_DMNUMTXHRLBCK { 33561300; }
sub TA_MINOR { 33560752; }
sub TA_CURACCESSERS { 33560666; }
sub TA_DMTXPARENT { 167779044; }
sub TA_DMMACHINETYPE { 197773675; }
sub TA_RDOMAIN { 167778972; }
sub TA_EVENT_FILTER_BINARY { 201333545; }
sub TA_DMNUMCONVRSND { 33561293; }
sub TA_OPERATION { 167778172; }
sub TA_HWMCONNCREATED { 63555521; }
sub TA_PREFERENCES { 167778633; }
sub TA_DMOUTRECSTYPE { 167779092; }
sub TA_DMLACCESSPOINT { 197773663; }
sub TA_DEVSIZE { 33560691; }
sub TA_DMSYMDESTNAME { 167778925; }
sub TA_CURRLOAD { 33560677; }
sub TA_ACLCACHEHITS { 33560878; }
sub TA_CURSTYPE { 33560682; }
sub TA_USERLOG { 167779128; }
sub TA_DMEXTENSIONS { 167779084; }
sub TA_MSG_LRPID { 33560758; }
sub TA_CURENCRYPTBITS { 167778654; }
sub TA_MSGSIZE { 33561062; }
sub TA_DMACN { 167778946; }
sub TA_DBHOST { 197773229; }
sub TA_OLDENCRYPT { 167778657; }
sub TA_SCANUNIT { 33560802; }
sub TA_CONNOSRVID { 33560657; }
sub TA_PERSISTENCE { 167778811; }
sub TA_ENDTIME { 33560693; }
sub TA_HWMACHINES { 33560717; }
sub TA_DMAUDITLOG { 167778958; }
sub TA_DMPRIO { 6833; }
sub TA_CLIENTID { 167778371; }
sub TA_SVCTIMEOUT { 33560825; }
sub TA_QCTL_QTIME_REL { 6957; }
sub TA_DMTPTRANID { 197773714; }
sub TA_DMRACCESSPOINTLIST { 197773728; }
sub TA_ERRORQNAME { 167778776; }
sub TA_TIMESTART { 33560831; }
sub TA_PID { 33560784; }
sub TA_TLOGCOUNT { 33560832; }
sub TA_BLOB_TYPE { 167779132; }
sub TA_APPDIR { 167778361; }
sub TA_DMTXTOTRLBCK { 63555982; }
sub TA_MAXWSCLIENTS { 33560749; }
sub TA_DMTLOGSIZE { 33561233; }
sub TA_CLASSPATH { 197773170; }
sub TA_DMINRECTYPE { 167779089; }
sub TA_DBUSER { 197773226; }
sub TA_DMLCONVTOTFAIL { 63555957; }
sub TA_DMBRANCHCOUNT { 63555989; }
sub TA_MAXINITTIME { 33560900; }
sub TA_PMID { 167778513; }
sub TA_CURRTDATA { 33560679; }
sub TA_VALIDATION { 167778597; }
sub TA_MSGENDTIME { 167778789; }
sub TA_MAXMACHINES { 33560742; }
sub TA_CURINTERFACES { 33560949; }
sub TA_CONNAVAILABLE { 63555519; }
sub TA_REFRESH { 63555513; }
sub TA_CONTIME { 33560663; }
sub TA_DMCMPLIMIT { 33561332; }
sub TA_CURMSG { 33561044; }
sub TA_QNAME { 167779115; }
sub TA_CURMACHINES { 33560673; }
sub TA_DMTYPE { 167778955; }
sub TA_HITICKET { 33560710; }
sub TA_MINHANDLERS { 33560902; }
sub TA_RPPERM { 33560797; }
sub TA_SEQUENCE { 33560809; }
sub TA_PRINNAME { 167778637; }
sub TA_CURACTIONS { 33561085; }
sub TA_DMRACCESSPOINT { 197773664; }
sub TA_RCVDNUM { 33560790; }
sub TA_TOTIDLTIME { 33560915; }
sub TA_DOMAINID { 167778420; }
sub TA_DMNETID { 167778923; }
sub TA_TUXOFFSET { 33560857; }
sub TA_TMDEBUG { 167778567; }
sub TA_DMAEQ { 167778943; }
sub TA_SENTNUM { 33560808; }
sub TA_ERROR { 33560438; }
sub TA_DMAET { 167778945; }
sub TA_NETTIMEOUT { 33560937; }
sub TA_MAXDRT { 33560738; }
sub TA_DMNWADDR { 167778936; }
sub TA_SEMID { 33560804; }
sub TA_FACTPERM { 33560888; }
sub TA_DMTPSUTTYPE { 167779094; }
sub TA_DMMULTIPLEXING { 6925; }
sub TA_HWPROC { 33561052; }
sub TA_DMSNADOM { 167778920; }
sub TA_SHM_DTIME { 33560819; }
sub TA_DMXATMIENCODING { 197773722; }
sub TA_CURCURSORS { 33561086; }
sub TA_MSG_QBYTES { 33560760; }
sub TA_STATE { 167778174; }
sub TA_MSG_LSPID { 33560759; }
sub TA_CLOPT { 167778372; }
sub TA_CUREXTENT { 33561043; }
sub TA_DMTXNUMACT { 63555978; }
sub TA_ULOGPFX { 167778592; }
sub TA_CUROWNERS { 33561091; }
sub TA_DMSECURITY { 167778967; }
sub TA_DMLCONVTOT { 63555956; }
sub TA_DRIVER { 197773223; }
sub TA_DMRCONVTOTFAIL { 63555969; }
sub TA_ULOGCAT { 167778588; }
sub TA_CMTRET { 167778379; }
sub TA_DMSNACRM { 167779069; }
sub TA_CONV { 167778392; }
sub TA_AEQLEN { 6784; }
sub TA_SERVERNAME { 167778539; }
sub TA_DMACCESSPOINTID { 197773662; }
sub TA_DUMMYDOMSTATS { 6840; }
sub TA_DMSTATISTICS { 6846; }
sub TA_MAXWSHPORT { 33560923; }
sub TA_TESTONRELEASE { 197773243; }
sub TA_WSPROTO { 33560919; }
sub TA_INTERN_TACTSRVID { 63555445; }
sub TA_ACN2 { 6787; }
sub TA_NUMTRAN { 33560777; }
sub TA_CURDISPATCHTHREADS { 33560962; }
sub TA_ENCPASSWD { 167779036; }
sub TA_HWDRT { 33560714; }
sub TA_DMDNSRESOLUTION { 167779086; }
sub TA_MAXQUEUELEN { 33560972; }

1; #
